==> bonita-server-6.2.5-sources.jar: org/bonitasoft/engine/core/process/instance/model/builder/SProcessInstanceBuilderFactory.java <==
/**
 * Copyright (C) 2011-2012 BonitaSoft S.A.
 * BonitaSoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.core.process.instance.model.builder;

import org.bonitasoft.engine.core.process.definition.model.SProcessDefinition;

/**
 * @author Baptiste Mesta
 * @author Yanyan Liu
 * @author Matthieu Chaffotte
 * @author Elias Ricken de Medeiros
 * @author Celine Souchet
 */
public interface SProcessInstanceBuilderFactory {

    SProcessInstanceBuilder createNewInstance(String name, long processDefinitionId);

    SProcessInstanceBuilder createNewInstance(String name, long processDefinitionId, String description);

    SProcessInstanceBuilder createNewInstance(SProcessDefinition definition);

    String getIdKey();

    String getNameKey();

    String getProcessDefinitionIdKey();

    String getStateIdKey();

    String getStateCategoryKey();

    String getStartDateKey();

    String getStartedByKey();

    String getStartedByDelegateKey();

    String getEndDateKey();

    String getLastUpdateKey();

    String getContainerIdKey();

    String getInterruptingEventIdKey();

    String getMigrationPlanIdKey();

    String getCallerIdKey();

}

==> bonita-server-6.3.1-sources.jar: org/bonitasoft/engine/core/process/instance/model/builder/SProcessInstanceBuilderFactory.java <==
/**
 * Copyright (C) 2011-2012 BonitaSoft S.A.
 * BonitaSoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.core.process.instance.model.builder;

import org.bonitasoft.engine.core.process.definition.model.SProcessDefinition;

/**
 * @author Baptiste Mesta
 * @author Yanyan Liu
 * @author Matthieu Chaffotte
 * @author Elias Ricken de Medeiros
 * @author Celine Souchet
 */
public interface SProcessInstanceBuilderFactory {

    SProcessInstanceBuilder createNewInstance(String name, long processDefinitionId);

    SProcessInstanceBuilder createNewInstance(String name, long processDefinitionId, String description);

    SProcessInstanceBuilder createNewInstance(SProcessDefinition definition);

    String getIdKey();

    String getNameKey();

    String getProcessDefinitionIdKey();

    String getStateIdKey();

    String getStateCategoryKey();

    String getStartDateKey();

    String getStartedByKey();

    String getStartedBySubstituteKey();

    String getEndDateKey();

    String getLastUpdateKey();

    String getContainerIdKey();

    String getInterruptingEventIdKey();

    String getMigrationPlanIdKey();

    String getCallerIdKey();

}
